@@ -1050,7 +1050,7 @@ COREUTILS-FINAL vs. COREUTILS, etc."
     (description
      "This package provides a complete GCC tool chain for C/C++ development to
 be installed in user profiles.  This includes GCC, as well as libc (headers
-and binaries, plus debugging symbols in the 'debug' output), and Binutils.")
+and binaries, plus debugging symbols in the @code{debug} output), and Binutils.")
     (home-page "https://gcc.gnu.org/")
     (outputs '("out" "debug" "static"))
 
@@ -1085,4 +1085,7 @@ and binaries, plus debugging symbols in the 'debug' output), and Binutils.")
 (define-public gcc-toolchain-8
   (make-gcc-toolchain gcc-8))
 
+(define-public gcc-toolchain-9
+  (make-gcc-toolchain gcc-9))
+
 ;;; commencement.scm ends here
