@@ -34,7 +34,7 @@
               (base32
                "1jk42cjaggk71rimjnx3qpmb6hivps0917vl3z7wbxk3i2whb98j"))))
     (build-system gnu-build-system)
-    (home-page "http://www.gnu.org/software/cppi/")
+    (home-page "https://www.gnu.org/software/cppi/")
     (synopsis "Indent C preprocessor directives to reflect nesting and more")
     (description
      "GNU Cppi processes C source code files to properly indent the
