@@ -2,10 +2,11 @@
 ;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
 ;;; Copyright © 2014 Manolis Fragkiskos Ragkousis <manolis837@gmail.com>
 ;;; Copyright © 2016 Hartmut Goebel <h.goebel@crazy-compilers.com>
-;;; Copyright © 2016 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2016, 2018 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2016 Efraim Flashner <efraim@flashner.co.il>
 ;;; Copyright © 2017 Jonathan Brielmaier <jonathan.brielmaier@web.de>
 ;;; Copyright © 2017 Julien Lepiller <julien@lepiller.eu>
+;;; Copyright © 2018, 2019 Tobias Geerinckx-Rice <me@tobias.gr>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -30,10 +31,12 @@
   #:use-module (gnu packages)
   #:use-module (guix build-system cmake)
   #:use-module (guix build-system gnu)
+  #:use-module (guix build-system python)
   #:use-module (gnu packages bison)
   #:use-module (gnu packages compression)
   #:use-module (gnu packages flex)
   #:use-module (gnu packages elf)
+  #:use-module (gnu packages pciutils)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages libusb)
   #:use-module (gnu packages libftdi)
@@ -45,15 +48,15 @@
 (define-public flashrom
   (package
     (name "flashrom")
-    (version "0.9.9")
+    (version "1.0.1")
     (source (origin
               (method url-fetch)
               (uri (string-append
-                    "https://download.flashrom.org/releases/flashrom-"
+                    "https://download.flashrom.org/releases/flashrom-v"
                     version ".tar.bz2"))
               (sha256
                (base32
-                "0i9wg1lyfg99bld7d00zqjm9f0lk6m0q3h3n9c195c9yysq5ccfb"))))
+                "0i6yrrl69hrqmwd7azj7x3j46m0qpvzmk3b5basym7mnlpfzhyfm"))))
     (build-system gnu-build-system)
     (inputs `(("dmidecode" ,dmidecode)
               ("pciutils" ,pciutils)
@@ -61,13 +64,14 @@
               ("libftdi" ,libftdi)))
     (native-inputs `(("pkg-config" ,pkg-config)))
     (arguments
-     '(#:make-flags (list "CC=gcc"
-                          (string-append "PREFIX=" %output)
-                          "CONFIG_ENABLE_LIBUSB0_PROGRAMMERS=no")
-       #:tests? #f   ; no 'check' target
+     '(#:make-flags
+       (list "CC=gcc"
+             (string-append "PREFIX=" %output)
+             "CONFIG_ENABLE_LIBUSB0_PROGRAMMERS=no")
+       #:tests? #f                      ; no 'check' target
        #:phases
        (modify-phases %standard-phases
-         (delete 'configure)
+         (delete 'configure)            ; no configure script
          (add-before 'build 'patch-exec-paths
            (lambda* (#:key inputs #:allow-other-keys)
              (substitute* "dmi.c"
@@ -76,7 +80,7 @@
                         (string-append (assoc-ref inputs "dmidecode")
                                        "/sbin/dmidecode"))))
              #t)))))
-    (home-page "http://flashrom.org/")
+    (home-page "https://flashrom.org/")
     (synopsis "Identify, read, write, erase, and verify ROM/flash chips")
     (description
      "flashrom is a utility for identifying, reading, writing,
@@ -89,25 +93,28 @@ programmer devices.")
 (define-public 0xffff
   (package
     (name "0xffff")
-    (version "0.7")
+    (version "0.8")
     (source
      (origin
-      (method url-fetch)
-      (uri (string-append "https://github.com/pali/0xffff/archive/"
-                          version ".tar.gz"))
-      (file-name (string-append "0xFFFF" version ".tar.gz" ))
-      (sha256
-       (base32
-        "1g4032c81wkk37wvbg1dxcqq6mnd76y9x7f2crmzqi6z4q9jcxmj"))))
+       (method git-fetch)
+       (uri (git-reference
+             (url "https://github.com/pali/0xffff.git")
+             (commit version)))
+       (file-name (git-file-name name version))
+       (sha256
+        (base32 "1a5b7k96vzirb0m8lqp7ldn77ppz4ngf56wslhsj2c6flcyvns4v"))))
     (build-system gnu-build-system)
     (inputs
-     `(("libusb",libusb-0.1))) ; doesn't work with libusb-compat
+     `(("libusb" ,libusb-0.1)))         ; doesn't work with libusb-compat
     (arguments
      '(#:phases
        (modify-phases %standard-phases
-         (delete 'configure)) ; no configure
-       #:make-flags (list (string-append "PREFIX=" %output))
-       #:tests? #f)) ; no 'check' target
+         (delete 'configure))           ; no configure
+       #:make-flags
+       (list "CC=gcc"
+             "BUILD_DATE=GNU Guix"
+             (string-append "PREFIX=" %output))
+       #:tests? #f))                    ; no 'check' target
     (home-page "https://github.com/pali/0xFFFF")
     (synopsis "Flash FIASCO images on Maemo devices")
     (description
@@ -120,15 +127,14 @@ brick your device.")
 (define-public avrdude
   (package
     (name "avrdude")
-    (version "6.1")
+    (version "6.3")
     (source
      (origin
       (method url-fetch)
       (uri (string-append "mirror://savannah/avrdude/avrdude-"
                           version ".tar.gz"))
       (sha256
-       (base32
-        "0frxg0q09nrm95z7ymzddx7ysl77ilfbdix1m81d9jjpiv5bm64y"))))
+       (base32 "15m1w1qad3dj7r8n5ng1qqcaiyx1gyd6hnc3p2apgjllccdp77qg"))))
     (build-system gnu-build-system)
     (inputs
      `(("libelf" ,libelf)
@@ -137,12 +143,12 @@ brick your device.")
     (native-inputs
      `(("bison" ,bison)
        ("flex" ,flex)))
-    (home-page "http://www.nongnu.org/avrdude/")
+    (home-page "https://www.nongnu.org/avrdude/")
     (synopsis "AVR downloader and uploader")
     (description
      "AVRDUDE is a utility to download/upload/manipulate the ROM and
-EEPROM contents of AVR microcontrollers using the in-system programming
-technique (ISP).")
+EEPROM contents of AVR microcontrollers using the @acronym{ISP, in-system
+programming} technique.")
     (license license:gpl2+)))
 
 (define-public dfu-programmer
@@ -297,8 +303,8 @@ RK3036, RK3066, RK312X, RK3168, RK3188, RK3288, RK3368.")
                 "1y7gwg3lipyp2zcysm2vid1qg5nwin9bxbvgzs28lz2rya4fz6sq"))))
     (build-system cmake-build-system)
     (arguments
-     `(#:configure-flags '("-DCMAKE_BUILD_TYPE=Release")
-       #:tests? #f; no tests
+     `(#:build-type "Release"
+       #:tests? #f                      ; no tests
        #:phases
        (modify-phases %standard-phases
          (add-after 'unpack 'patch-invocations
@@ -329,3 +335,143 @@ USB and interacts with low-level software running on the device, known as Loke.
 Loke and Heimdall communicate via the custom Samsung-developed protocol typically
 referred to as the \"Odin 3 protocol\".")
     (license license:expat)))
+
+(define-public ifdtool
+  (package
+    (name "ifdtool")
+    (version "4.9")
+    (source (origin
+              (method git-fetch)
+              (uri (git-reference
+                    (url "https://github.com/coreboot/coreboot.git")
+                    (commit version)))
+              (file-name (git-file-name name version))
+              (sha256
+               (base32
+                "0jidj29jh6p65d17k304wlzhxvp4p3c2namgcdwg2sxq8jfr0zlm"))))
+    (build-system gnu-build-system)
+    (arguments
+     `(#:make-flags
+       (list "CC=gcc"
+             "INSTALL=install"
+             (string-append "PREFIX=" (assoc-ref %outputs "out")))
+       #:phases
+       (modify-phases %standard-phases
+         (add-after 'unpack 'chdir
+           (lambda _
+             (chdir "util/ifdtool")
+             #t))
+         (delete 'configure))           ; no configure script
+       #:tests? #f))                    ; no test suite
+    (home-page "https://github.com/corna/me_cleaner/")
+    (synopsis "Intel Firmware Descriptor dumper")
+    (description "This package provides @command{ifdtool}, a program to
+dump Intel Firmware Descriptor data of an image file.")
+    (license license:gpl2)))
+
+(define-public intelmetool
+  (package
+    (name "intelmetool")
+    (version "4.7")
+    (source (origin
+              (method git-fetch)
+              (uri (git-reference
+                    (url "https://review.coreboot.org/p/coreboot")
+                    (commit version)))
+              (file-name (git-file-name name version))
+              (sha256
+               (base32
+                "0nw555i0fm5kljha9h47bk70ykbwv8ddfk6qhz6kfqb79vzhy4h2"))))
+    (build-system gnu-build-system)
+    (inputs
+     `(("pciutils" ,pciutils)
+       ("zlib" ,zlib)))
+    (arguments
+     `(#:make-flags
+       (list "CC=gcc"
+             "INSTALL=install"
+             (string-append "PREFIX=" (assoc-ref %outputs "out")))
+       #:phases
+       (modify-phases %standard-phases
+        (add-after 'unpack 'chdir
+          (lambda _
+            (chdir "util/intelmetool")
+            #t))
+        (delete 'configure)
+        (delete 'check))))
+    (home-page "https://github.com/zamaudio/intelmetool")
+    (synopsis "Intel Management Engine tools")
+    (description "This package provides tools for working with Intel
+Management Engine (ME).  You need to @code{sudo rmmod mei_me} and
+@code{sudo rmmod mei} before using this tool.  Also pass
+@code{iomem=relaxed} to the Linux kernel command line.")
+    (license license:gpl2)
+
+    ;; This is obviously an Intel thing, plus it requires <cpuid.h>.
+    (supported-systems '("x86_64-linux" "i686-linux"))))
+
+(define-public me-cleaner
+  (package
+    (name "me-cleaner")
+    (version "1.1")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "https://github.com/corna/me_cleaner/"
+                                  "archive/v" version ".tar.gz"))
+              (sha256
+               (base32
+                "1pgwdqy0jly80nhxmlmyibs343497yjzs6dwfbkcw0l1gjm8i5hw"))
+              (file-name (string-append name "-" version ".tar.gz"))))
+    (build-system python-build-system)
+    (arguments
+     `(#:phases
+       (modify-phases %standard-phases
+         (add-after 'unpack 'create-setup.py
+           (lambda _
+             (call-with-output-file "setup.py"
+               (lambda (port)
+                 (format port "\
+from setuptools import setup
+setup(name='me_cleaner', version='~a', scripts=['me_cleaner.py'])
+" ,version)))
+             #t)))))
+    (home-page "https://github.com/corna/me_cleaner")
+    (synopsis "Intel ME cleaner")
+    (description "This package provides tools for disabling Intel
+ME as far as possible (it only edits ME firmware image files).")
+    (license license:gpl3+)
+
+    ;; This is an Intel thing.
+    (supported-systems '("x86_64-linux" "i686-linux"))))
+
+(define-public uefitool
+  (package
+    (name "uefitool")
+    (version "0.22.4")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "https://github.com/LongSoft/UEFITool/archive/"
+                                  version ".tar.gz"))
+              (sha256
+               (base32
+                "05jmhv7jpq08kqbd1477y1lgyjvcic3njrd0bmzdy7v7b7lnhl82"))
+              (file-name (string-append name "-" version ".tar.gz"))))
+    (build-system gnu-build-system)
+    (arguments
+     `(#:phases
+       (modify-phases %standard-phases
+         (replace 'configure
+           (lambda _
+             (invoke "qmake" "-makefile")))
+         (replace 'install
+           (lambda* (#:key outputs #:allow-other-keys)
+             (install-file "UEFITool" (string-append (assoc-ref outputs "out")
+                                                     "/bin"))
+             #t)))))
+    (inputs
+     `(("qtbase" ,qtbase)))
+    (home-page "https://github.com/LongSoft/UEFITool/")
+    (synopsis "UEFI image editor")
+    (description "@code{uefitool} is a graphical image file editor for
+Unifinished Extensible Firmware Interface (UEFI) images.")
+    (license license:bsd-2)))
