@@ -1,10 +1,12 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2014, 2015, 2017 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2014, 2015, 2017, 2018 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2014 David Thompson <dthompson2@worcester.edu>
 ;;; Copyright © 2015, 2016 Ricardo Wurmus <rekado@elephly.net>
 ;;; Copyright © 2015 Alex Kost <alezost@gmail.com>
 ;;; Copyright © 2015, 2016 Efraim Flashner <efraim@flashner.co.il>
-;;; Copyright © 2017 Tobias Geerinckx-Rice <me@tobias.gr>
+;;; Copyright © 2017, 2018, 2019 Tobias Geerinckx-Rice <me@tobias.gr>
+;;; Copyright © 2018, 2019 Rutger Helling <rhelling@mykolab.com>
+;;; Copyright © 2018, 2019 Marius Bakke <mbakke@fastmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -26,7 +28,7 @@
   #:use-module (guix download)
   #:use-module (guix packages)
   #:use-module (guix build-system gnu)
-  #:use-module (gnu packages databases)
+  #:use-module (gnu packages dbm)
   #:use-module (gnu packages flex)
   #:use-module (gnu packages gawk)
   #:use-module (gnu packages groff)
@@ -38,7 +40,7 @@
 (define-public libpipeline
   (package
     (name "libpipeline")
-    (version "1.4.2")
+    (version "1.5.1")
     (source (origin
               (method url-fetch)
               (uri (string-append
@@ -46,7 +48,7 @@
                     version ".tar.gz"))
               (sha256
                (base32
-                "1gkrfqkphdc6gk8gic68asallj59i3cfq6nd31ppks0cljdgrwgy"))))
+                "0bwh5xz5f2czwb7f564jz1mp4znm8pldnvf65fs0hpw4gmmp0cyn"))))
     (build-system gnu-build-system)
     (home-page "http://libpipeline.nongnu.org/")
     (synopsis "C library for manipulating pipelines of subprocesses")
@@ -58,14 +60,14 @@ a flexible and convenient way.")
 (define-public man-db
   (package
     (name "man-db")
-    (version "2.7.6.1")
+    (version "2.8.5")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://savannah/man-db/man-db-"
                                   version ".tar.xz"))
               (sha256
                (base32
-                "0gqgs4zc3r87apns0k5qp689p2ylxx2596s2mkmkxjjay99brv88"))))
+                "1hgnfcgbllmws8cs6zaxklq8b69i05zynxi87f3zxw9lfms54kdn"))))
     (build-system gnu-build-system)
     (arguments
      `(#:phases
@@ -79,12 +81,21 @@ a flexible and convenient way.")
                              (("#! /bin/sh")
                               (string-append "#!" (which "sh")))))
                          (remove file-is-directory?
-                                 (find-files "src/tests" ".*"))))))
-         (add-after 'unpack 'patch-iconv-path
+                                 (find-files "src/tests" ".*")))
+               #t)))
+         (add-after 'unpack 'patch-absolute-paths
            (lambda* (#:key inputs #:allow-other-keys)
              (substitute* "src/man.c"
                (("\"iconv\"")
                 (string-append "\"" (which "iconv") "\"")))
+             ;; Embed an absolute reference to "preconv", otherwise it
+             ;; falls back to searching in PATH and ultimately fails
+             ;; to render unicode data (see <https://bugs.gnu.org/30785>).
+             (substitute* "lib/encodings.c"
+               (("groff_preconv = NULL")
+                (string-append "groff_preconv = \""
+                               (assoc-ref inputs "groff-minimal")
+                               "/bin/preconv\"")))
              #t)))
        #:configure-flags
        (let ((groff (assoc-ref %build-inputs "groff"))
@@ -106,8 +117,9 @@ a flexible and convenient way.")
                        (string-append "--with-bzip2=" bzip2 "/bin/gzip")
                        (string-append "--with-xz=" xz "/bin/xz")
                        (string-append "--with-col=" util "/bin/col")
-                       ;; Default value is "/usr/lib/tmpfiles.d" (not
-                       ;; prefix-sensitive).
+                       ;; The default systemd directories ignore --prefix.
+                       (string-append "--with-systemdsystemunitdir="
+                                      %output "/lib/systemd/system")
                        (string-append "--with-systemdtmpfilesdir="
                                       %output "/lib/tmpfiles.d"))
                  (map (lambda (prog)
@@ -131,6 +143,9 @@ a flexible and convenient way.")
        ("groff-minimal" ,groff-minimal)
        ("less" ,less)
        ("libpipeline" ,libpipeline)
+       ;; FIXME: 4.8 and later can use libseccomp, but it causes test
+       ;; failures in the build chroot.
+       ;;("libseccomp" ,libseccomp)
        ("util-linux" ,util-linux)))
     (native-search-paths
      (list (search-path-specification
@@ -147,20 +162,17 @@ the traditional flat-text whatis databases.")
 (define-public man-pages
   (package
     (name "man-pages")
-    (version "4.14")
-    (source (origin
-              (method url-fetch)
-              (uri
-                (list
-                  (string-append
-                    "mirror://kernel.org/linux/docs/man-pages/man-pages-"
-                    version ".tar.xz")
-                  (string-append
-                    "mirror://kernel.org/linux/docs/man-pages/Archive/"
-                    "man-pages-" version ".tar.xz")))
-              (sha256
-               (base32
-                "0wf9ymqxk1k5xwcl3n919p66a1aayif3x4cahj4w04y3k1wbhlih"))))
+    (version "5.01")
+    (source
+     (origin
+       (method url-fetch)
+       (uri
+        (list (string-append "mirror://kernel.org/linux/docs/man-pages/"
+                             "man-pages-" version ".tar.xz")
+              (string-append "mirror://kernel.org/linux/docs/man-pages/Archive/"
+                             "man-pages-" version ".tar.xz")))
+       (sha256
+        (base32 "09xn8d8xxwgms6h1bvjlgn3mxz51vxf3ra0ry9f5dqi29qry3z3x"))))
     (build-system gnu-build-system)
     (arguments
      '(#:phases (modify-phases %standard-phases (delete 'configure))
@@ -186,7 +198,7 @@ Linux kernel and C library interfaces employed by user-space programs.")
 (define-public help2man
   (package
     (name "help2man")
-    (version "1.47.4")
+    (version "1.47.6")
     (source
      (origin
       (method url-fetch)
@@ -194,7 +206,7 @@ Linux kernel and C library interfaces employed by user-space programs.")
                           version ".tar.xz"))
       (sha256
        (base32
-        "0lvp4306f5nq08f3snffs5pp1zwv8l35z6f5g0dds51zs6bzdv6l"))))
+        "0vz4dlrvy4vc6l7w0a7n668pfa0rdm73wr2gar58wqranyah46yr"))))
     (build-system gnu-build-system)
     (arguments `(;; There's no `check' target.
                  #:tests? #f))
@@ -212,6 +224,49 @@ Linux kernel and C library interfaces employed by user-space programs.")
 automatically.")
     (license gpl3+)))
 
+(define-public help2man/latest
+  (package
+    (inherit help2man)
+    (version "1.47.8")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://gnu/help2man/help2man-"
+                                  version ".tar.xz"))
+              (sha256
+               (base32
+                "1p5830h88cx0zn0snwaj0vpph81xicpsirfwlxmcgjrlmn0nm3sj"))))))
+
+(define-public scdoc
+  (package
+   (name "scdoc")
+   (version "1.9.4")
+   (source
+    (origin
+     (method url-fetch)
+     (uri (string-append "https://git.sr.ht/%7Esircmpwn/scdoc/archive/" version
+                         ".tar.gz"))
+     (file-name (string-append name "-" version ".tar.gz"))
+     (sha256
+      (base32
+       "00zc3rzj97gscby31djlqyczvqpyhrl66i44czwzmmn7rc5j03m1"))))
+   (build-system gnu-build-system)
+   (arguments
+    `(#:make-flags '("CC=gcc")
+      #:phases
+      (modify-phases %standard-phases
+        (delete 'configure)
+        (add-before 'install 'hardcode-paths
+          (lambda* (#:key outputs #:allow-other-keys)
+            (substitute* "Makefile"
+                         (("/usr/local") (assoc-ref outputs "out")))
+            #t)))))
+   (home-page "https://git.sr.ht/~sircmpwn/scdoc")
+   (synopsis "Simple man page generator")
+   (description "scdoc is a simple man page generator written for POSIX systems
+in C99.")
+   ;; MIT license, see /share/doc/scdoc-1.6.0/COPYING.
+   (license expat)))
+
 (define-public txt2man
   (package
     (name "txt2man")
