@@ -1,7 +1,8 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013, 2017 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2017, 2018 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2014 Eric Bavier <bavier@member.fsf.org>
 ;;; Copyright © 2016 Efraim Flashner <efraim@flashner.co.il>
+;;; Copyright © 2018 Tobias Geerinckx-Rice <me@tobias.gr>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -40,14 +41,14 @@
 (define-public zile
   (package
     (name "zile")
-    (version "2.4.13")
+    (version "2.4.14")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnu/zile/zile-"
                                  version ".tar.gz"))
              (sha256
               (base32
-               "03mcg0bxkzprlsx8y6h22w924pzx4a9zr7zm3g11j8j3x9lz75f7"))))
+               "0x3byaddms8l3g7igx6njycqsq98wgapysdb5c7lhcnajlkp8y3s"))))
     (build-system gnu-build-system)
     (arguments
      '(#:phases
@@ -102,7 +103,7 @@ default Emacs configuration, but it carries a much lighter feature set.")
          ,@(package-inputs zile)))
       (native-inputs
        `(("m4" ,m4)                               ;for 'bootstrap'
-         ("autoconf" ,(autoconf-wrapper))
+         ("autoconf" ,autoconf-wrapper)
          ("automake" ,automake)
 
          ;; For some reason, 'bootstrap' insists on having these.
@@ -114,7 +115,7 @@ default Emacs configuration, but it carries a much lighter feature set.")
        (substitute-keyword-arguments (package-arguments zile)
          ((#:phases phases)
           `(modify-phases ,phases
-             (add-after 'unpack 'bootstrap
+             (replace 'bootstrap
                (lambda _
                  ;; Make sure all the files are writable so that ./bootstrap
                  ;; can proceed.
@@ -122,10 +123,10 @@ default Emacs configuration, but it carries a much lighter feature set.")
                              (chmod file #o755))
                            (find-files "."))
                  (patch-shebang "gnulib/gnulib-tool")
-                 (zero? (system* "sh" "./bootstrap"
-                                 "--gnulib-srcdir=gnulib"
-                                 "--skip-git" "--skip-po"
-                                 "--verbose"))))
+                 (invoke "sh" "./bootstrap"
+                         "--gnulib-srcdir=gnulib"
+                         "--skip-git" "--skip-po"
+                         "--verbose")))
              (add-after 'install 'wrap-command
                (lambda* (#:key outputs #:allow-other-keys)
                  ;; Add zile.scm to the search path.
